@@ -18,19 +18,27 @@ nrfa_api <- function(webservice, parameters, path = "") {
 
   # Check response
   if (httr::http_error(resp)) {
-    stop(
+    message(
       sprintf("NRFA API request failed [%s]", httr::status_code(resp)),
       call. = FALSE
     )
+    return(NULL)
   }
 
   # Check output format
   if (httr::http_type(resp) != "application/json") {
-    stop("API did not return json", call. = FALSE)
+    message("API did not return json", call. = FALSE)
+    return(NULL)
   }
 
   # Parse content
-  page_content <- httr::content(resp, "text", encoding = "UTF-8")
+  page_content <- try(httr::content(resp, "text", encoding = "UTF-8"))
+  if (class(page_content) == "try-error") {
+    errs <- geterrmessage()
+    message(paste("An unknwon error occurred when accessing the data",
+                  "- with error message:", errs))
+    return(NULL)
+  }
   if (webservice == "station-ids") {
     parsed <- jsonlite::fromJSON(page_content, simplifyVector = TRUE)
   }
@@ -93,15 +101,16 @@ get_ts_internal <- function(id, type, metadata, verbose, full_info) {
         full_info) {
       station_info <- rnrfa::catalogue(column_name = "id",
                                        column_value = paste0("==", id))
-      if (type %in% c("pot-stage", "pot-flow")){
+      if (type %in% c("pot-stage", "pot-flow")) {
         rejected_periods <- unlist(station_info$`peak-flow-rejected-periods`,
                                    use.names = FALSE)
-        
-        periods <- vector(mode="numeric",length=0)
-        periods <- as.Date(periods,  origin="1970-01-01")
-        ### only do this when there are missing periods 
-        if(!is.null(rejected_periods)){
-          periods <- lapply(X = strsplit(rejected_periods, "[/]"), FUN = as.Date)
+
+        periods <- vector(mode = "numeric", length = 0)
+        periods <- as.Date(periods, origin = "1970-01-01")
+        ### only do this when there are missing periods
+        if (!is.null(rejected_periods)) {
+          periods <- lapply(X = strsplit(rejected_periods, "[/]"),
+                            FUN = as.Date)
           periods <- lapply(X = periods,
                             FUN = function(x) {
                               seq.Date(from = x[1], to = x[2], by = "day")
@@ -111,7 +120,7 @@ get_ts_internal <- function(id, type, metadata, verbose, full_info) {
         df$rejected <- ifelse(test = as.Date(datatime) %in% periods,
                               yes = TRUE, no = FALSE)
       }
-      if (type %in% c("amax-stage", "amax-flow")){
+      if (type %in% c("amax-stage", "amax-flow")) {
         years <- unlist(station_info$`peak-flow-rejected-amax-years`,
                         use.names = FALSE)
         water_year <- lubridate::year(datatime) +
@@ -140,27 +149,34 @@ get_ts_internal <- function(id, type, metadata, verbose, full_info) {
 }
 
 seasonal_averages_internal <- function(timeseries, season) {
-  
+
   # seasonal aggregation:
   # seasons are labelled by the calendar quarter in which the season ends
-  seasonal_mean <- aggregate(timeseries, zoo::as.yearqtr, mean) + 1/12
-  
-  if (season == "Winter") {quarter_number <- 1}
-  if (season == "Spring") {quarter_number <- 2}
-  if (season == "Summer") {quarter_number <- 3}
-  if (season == "Autumn") {quarter_number <- 4}
-  
+  seasonal_mean <- aggregate(timeseries, zoo::as.yearqtr, mean) + 1 / 12
+
+  if (season == "Winter") {
+    quarter_number <- 1
+  }
+  if (season == "Spring") {
+    quarter_number <- 2
+  }
+  if (season == "Summer") {
+    quarter_number <- 3
+  }
+  if (season == "Autumn") {
+    quarter_number <- 4
+  }
+
   # Get indices of the relevant season
   idx <- seq(quarter_number, length(seasonal_mean), 4)
   seasonal_mean <- seasonal_mean[idx]
-  
+
   # fit basic straight line
   fit <- stats::glm(seasonal_mean ~ seq(1, length(seasonal_mean)))
   # F-statistics of the significance test with the summary function
   # extract slope and p-value (for significance to be true, p should be < 0.05)
   co <- summary(fit)$coefficients[2, c(1, 4)] # only slope: coef(fit)[[2]]
-  
-  return(co)
-  
-}
 
+  return(co)
+
+}
